@@ -42,12 +42,16 @@ class AzBlobClient(ClientInterface):
             [f.name for f in self.get_container_client_from_path(path=path).list_blobs(name_starts_with=file_path)]
         return blob_list
 
-    def _get(self, path: str):
+    def _get(self, path: str, **kwargs):
         file_bytes = self.get_file_client_from_path(path=path).download_blob().readall()
         return file_bytes
 
     def _put(self, path: str, data):
-        self.get_file_client_from_path(path=path).upload_blob(data=data, length=len(data))
+        self.get_file_client_from_path(path=path).upload_blob(
+            data=data,
+            length=len(data),
+            overwrite=True
+        )
         return True
 
     def _info(self, path: str):
