@@ -1,4 +1,5 @@
 from typing import Union
+import importlib
 import re
 from azfs.error import (
     AzfsInputError
@@ -20,7 +21,7 @@ class BlobPathDecoder:
 
     @staticmethod
     def _decode_path_storage_account_name(path: str) -> (str, str, str, str):
-        url_pattern = r"https://([a-z0-9]*).(dfs|blob).core.windows.net/(.*)"
+        url_pattern = r"https://([a-z0-9]*).(dfs|blob|queue).core.windows.net/(.*)"
         result = re.match(url_pattern, path)
         if result:
             storage_account_name = result.group(1)
@@ -31,7 +32,7 @@ class BlobPathDecoder:
 
     @staticmethod
     def _decode_path_container_name(path: str) -> (str, str, str, str):
-        url_pattern = r"https://([a-z0-9]*).(dfs|blob).core.windows.net/(.*?)/"
+        url_pattern = r"https://([a-z0-9]*).(dfs|blob|queue).core.windows.net/(.*?)/"
         result = re.match(url_pattern, path)
         if result:
             storage_account_name = result.group(1)
@@ -42,7 +43,7 @@ class BlobPathDecoder:
 
     @staticmethod
     def _decode_path_blob_name(path: str) -> (str, str, str, str):
-        url_pattern = r"https://([a-z0-9]*).(dfs|blob).core.windows.net/(.*?)/(.+)"
+        url_pattern = r"https://([a-z0-9]*).(dfs|blob|queue).core.windows.net/(.*?)/(.+)"
         result = re.match(url_pattern, path)
         if result:
             storage_account_name = result.group(1)
@@ -54,7 +55,7 @@ class BlobPathDecoder:
 
     @staticmethod
     def _decode_path_without_url(path: str) -> (str, str, str, str):
-        url_pattern = r"(dfs|blob)/([a-z0-9]*)/(.+?)/(.*)"
+        url_pattern = r"(dfs|blob|queue)/([a-z0-9]*)/(.+?)/(.*)"
         result = re.match(url_pattern, path)
         if result:
             storage_account_name = result.group(2)
@@ -68,7 +69,7 @@ class BlobPathDecoder:
     def _decode_path(path: str) -> (str, str, str, str):
         """
         decode input [path] such as
-        * https://([a-z0-9]*).(dfs|blob).core.windows.net/(.*?)/(.*),
+        * https://([a-z0-9]*).(dfs|blob|queue).core.windows.net/(.*?)/(.*),
         * ([a-z0-9]*)/(.+?)/(.*)
 
         dfs: data_lake, blob: blob
@@ -160,3 +161,27 @@ def _ls_get_folder_name(file_path_list: list, file_path: str):
             if result:
                 folders_in_file_path.append(result.group(1))
     return list(set(folders_in_file_path))
+
+# =============== #
+# optional import #
+# =============== #
+
+
+def import_optional_dependency(name: str, extra: str = "", pypi_name: str = ""):
+    """
+    import package dynamically.
+    any package can import anywhere, since the package imported is kept singleton.
+    :param name: import package name
+    :param extra: message to be shown when raise ImportError
+    :param pypi_name: name for pip install
+    :return:
+    """
+    msg = (
+        f"Missing optional dependency '{name}'. {extra} "
+        f"Use pip or conda to install {pypi_name}."
+    )
+    try:
+        module = importlib.import_module(name)
+    except ImportError:
+        raise ImportError(msg) from None
+    return module
